@@ -1,9 +1,10 @@
 package t::boilerplate;
 
+use strict;
+use warnings;
 use File::Spec::Functions qw( catdir updir );
 use FindBin               qw( $Bin );
 use lib               catdir( $Bin, updir, 'lib' ), catdir( $Bin, 'lib' );
-use strictures::defanged;
 
 use Test::Requires { version => 0.88 };
 use Module::Build;
@@ -20,7 +21,8 @@ use Test::Requires "${perl_ver}";
 use Test::More;
 
 sub import {
-   strictures::defanged->import;
+   strict->import;
+   $] < 5.008 ? warnings->import : warnings->import( NONFATAL => 'all' );
 # 160dd1a2-1ebe-11e4-ae61-5739e0bfc7aa
 # 494fe6de-2168-11e4-b0d1-f6bc4915a708
    my $ref = warnings->can( 'bits' );
